@@ -1,4 +1,4 @@
-# Copyright 2021 VMware, Inc.
+# Copyright 2021-2023 VMware, Inc.
 # SPDX-License-Identifier: Apache-2.0
 import logging
 import os
@@ -30,7 +30,13 @@ class JobCreate:
 
     @ApiClientErrorDecorator()
     def create_job(
-        self, name: str, team: str, path: str, cloud: bool, local: bool
+        self,
+        name: str,
+        team: str,
+        path: str,
+        cloud: bool,
+        local: bool,
+        sample_job_directory: pathlib.Path = None,
     ) -> None:
         self.__validate_job_name(name)
         if local:
@@ -40,7 +46,7 @@ class JobCreate:
             self.__create_cloud_job(team, name)
         if local:
             job_path = self.__get_job_path(path, name)
-            self.__create_local_job(team, name, job_path)
+            self.__create_local_job(team, name, job_path, sample_job_directory)
             if cloud:
                 self.__download_key(team, name, path)
 
@@ -63,8 +69,10 @@ class JobCreate:
             f"Data Job with name {name} created and registered in cloud runtime by Control Service."
         )
 
-    def __create_local_job(self, team: str, name: str, job_path: str) -> None:
-        sample_job = self.__vdk_config.sample_job_directory
+    def __create_local_job(
+        self, team: str, name: str, job_path: str, sample_job_directory: pathlib.Path
+    ) -> None:
+        sample_job = self.__create_sample_job_dir(sample_job_directory)
         log.debug(f"Create sample job from directory: {sample_job} into {job_path}")
         cli_utils.copy_directory(sample_job, job_path)
         local_config = JobConfig(job_path)
@@ -72,6 +80,33 @@ class JobCreate:
             log.warning(f"Failed to write Data Job team {team} in config.ini.")
         log.info(f"Data Job with name {name} created locally in {job_path}.")
 
+    def __create_sample_job_dir(self, sample_job_directory: pathlib.Path):
+        """
+        This method generates the directory for the sample job which will be created when invoking `vdk create`.
+        Its control flow is as follows:
+         - if the configuration variable VDK_CONTROL_SAMPLE_JOB_DIRECTORY is set, it takes precedent over
+         everything else
+         - next, if a sample_job_directory is passed to the method by its invoking class, it takes precedent next; the
+         purpose of this is to allow plugins and extensions to set a new default sample job, but still not overwrite
+         one which was set by the user
+         - finally, the default sample job is used
+
+        :param sample_job_directory: a Python module containing the files for a sample job
+        :return: an absolute path in the current environment where the sample job is so the files located there can
+        be copied over to the target directory when creating a new job
+        """
+        if self.__vdk_config.sample_job_directory:
+            return self.__vdk_config.sample_job_directory
+
+        if sample_job_directory:
+            return sample_job_directory
+
+        import vdk.internal.control.job.sample_job
+
+        template_module_path = vdk.internal.control.job.sample_job.__path__._path[0]
+
+        return os.path.abspath(template_module_path)
+
     def __download_key(self, team, name, path):
         job_download_key = JobDownloadKey(self.__rest_api_url)
         try:
