@@ -1,4 +1,4 @@
-# Copyright 2021 VMware, Inc.
+# Copyright 2021-2023 VMware, Inc.
 # SPDX-License-Identifier: Apache-2.0
 import os
 from enum import Enum
@@ -178,11 +178,9 @@ def deploy(
             job_version = get_or_prompt("Job Version", job_version)
         if job_path:
             reason = get_or_prompt("Reason", reason)
-            return cmd.create(
-                name, team, job_path, reason, output, vdk_version, enabled
-            )
+            return cmd.create(name, team, job_path, reason, vdk_version, enabled)
         else:
-            return cmd.update(name, team, enabled, job_version, vdk_version, output)
+            return cmd.update(name, team, enabled, job_version, vdk_version)
     if operation == DeployOperation.REMOVE.value:
         name = get_or_prompt("Job Name", name)
         team = get_or_prompt("Job Team", team)
@@ -190,10 +188,10 @@ def deploy(
     if operation == DeployOperation.SHOW.value:
         name = get_or_prompt("Job Name", name)
         team = get_or_prompt("Job Team", team)
-        return cmd.show(name, team, output)
+        return cmd.show(name, team)
     if operation == DeployOperation.CREATE.value:
         job_path = get_or_prompt("Job Path", job_path)
         default_name = os.path.basename(job_path)
         name = get_or_prompt("Job Name", name, default_name)
         reason = get_or_prompt("Reason", reason)
-        return cmd.create(name, team, job_path, reason, output, vdk_version, enabled)
+        return cmd.create(name, team, job_path, reason, vdk_version, enabled)
