@@ -1,13 +1,15 @@
-# Copyright 2021 VMware, Inc.
+# Copyright 2021-2023 VMware, Inc.
 # SPDX-License-Identifier: Apache-2.0
 import logging
 import os
 import pathlib
+import platform
 import sys
 from configparser import ConfigParser
 from pathlib import Path
 
 from vdk.internal.control.exception.vdk_exception import VDKException
+from vdk.internal.control.utils import version_utils
 from vdk.internal.control.utils.control_utils import read_config_ini_file
 
 log = logging.getLogger(__name__)
@@ -21,7 +23,7 @@ class VDKConfig:
 
     _user_agent = os.environ.get(
         "VDK_CONTROL_SERVICE_USER_AGENT",
-        f"vdk-control-cli/1.2 ({os.name}; {sys.platform})" + sys.version.split(" ")[0],
+        f"vdk-control-cli/{version_utils.__version__} ({sys.platform}; {platform.platform()}; ) Python {platform.python_version()}",
     )
 
     @property
@@ -127,13 +129,7 @@ class VDKConfig:
 
     @property
     def sample_job_directory(self) -> str:
-        sample_job_dir = os.getenv("VDK_CONTROL_SAMPLE_JOB_DIRECTORY", None)
-        if not sample_job_dir:
-            import vdk.internal.control.job.sample_job
-
-            template_module_path = vdk.internal.control.job.sample_job.__path__._path[0]
-            sample_job_dir = os.path.abspath(template_module_path)
-        return sample_job_dir
+        return os.getenv("VDK_CONTROL_SAMPLE_JOB_DIRECTORY", None)
 
 
 class VDKConfigFolder:
